@@ -1,6 +1,6 @@
 #' Indicate version updates of the packages inside SIPDIBGE
 #' @description This function describes version updates of the packages inside SIPDIBGE.
-#' @import COVIDIBGE PNADcIBGE PNSIBGE POFIBGE cli graphics grDevices png purrr rstudioapi tibble utils
+#' @import COVIDIBGE PNADcIBGE PNSIBGE cli graphics grDevices png purrr rstudioapi tibble utils
 #' @param survey Name of the household survey for reference package information. If \code{NULL}, presents the information of all the packages inside this collection.
 #' @return A vector with version updates of the packages inside SIPDIBGE.
 #' @note For more information, visit the survey official website <\url{https://www.ibge.gov.br/}> and consult the other functions of this package, described below.
@@ -13,9 +13,7 @@
 #' # Presenting information about the PNADcIBGE package
 #' sipd_update(survey="PNADC")
 #' # Presenting information about the PNSIBGE package
-#' sipd_update(survey="PNS")
-#' # Presenting information about the POFIBGE package
-#' sipd_update(survey="POF")}
+#' sipd_update(survey="PNS")}
 #' @export
 
 sipd_update <- function(survey = NULL) {
@@ -35,10 +33,10 @@ sipd_update <- function(survey = NULL) {
     infos <- sipd_sitrep(survey="PNS")
     updts <- infos[infos$former==TRUE,]
   }
-  else if (toupper(survey) == "POF") {
-    infos <- sipd_sitrep(survey="POF")
-    updts <- infos[infos$former==TRUE,]
-  }
+  # else if (toupper(survey) == "POF") {
+  #   infos <- sipd_sitrep(survey="POF")
+  #   updts <- infos[infos$former==TRUE,]
+  # }
   else {
     infos <- sipd_sitrep()
     updts <- infos[infos$former==TRUE,]
